@@ -3,7 +3,7 @@
 #' 
 #' @param x numeric. The angle to be converted.
 #' @param from,to character. Units to convert from and to. Can be 
-#' "radians" or "degrees" or any partial match.
+#'   "radians" or "degrees" or any partial match (case-sensitive).
 #' 
 #' @author Eric Archer \email{eric.archer@@noaa.gov}
 #' 
@@ -13,21 +13,18 @@
 #' 
 #' @export
 #' 
-convert.angle <- function(x, from = "degrees", to = "radians") {
-  units <- c("degrees", "radians")
-  from <- units[pmatch(tolower(from), units)]
-  to <- units[pmatch(tolower(to), units)]
+convert.angle <- function(x, from = c("degrees", "radians"), to = c("radians", "degrees")) {
+  from <- match.arg(from)
+  to <- match.arg(to)
   
   x <- switch(from,
     degrees = x,
-    radians = x * 180 / pi,
-    NA
+    radians = x * 180 / pi
   )
   
   result <- switch(to,
     degrees = x,
-    radians = x * pi / 180,
-    NA
+    radians = x * pi / 180
   )
   
   as.numeric(result)
