@@ -3,11 +3,9 @@
 #' SWFSC Miscellaneous Functions
 #' 
 #' @aliases swfscMisc-package
-#' @docType package
 #' @name swfscMisc
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
-NULL
+"_PACKAGE"
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 ##if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
